Attribute VB_Name = "RunTest"
' Modified by Ryan J. Stradling - Real3D
' April 30, 1998
' Added reporting of system info and changed the
' reporting mechanism to seconds and not
' normalized values

Const CompleteTest = 1
Const GraphicsTest = 2
Const FloatingPointTest = 3
Const IOTest = 4

Const CompleteTime = 1
Const GraphicsTime = 2
Const FPTime = 3
Const IOTime = 4

Const ResetTimer = 0
Const StartTimer = 1
Const StopTimer = 2
Const GetElapsed = 3
Const GetRunning = 4

Dim TestWhat As Integer

Dim Part As Object
Dim swPart As Object
Dim swAssembly As Object
Dim swSubAssembly As Object
Dim swDrawing As Object


Static Function BenchTime(WhichTime As Integer, Action As Integer) As Single

    Dim TimeNow, StartTime(4), ElapsedTime(4) As Single
    Dim I As Integer

    DoEvents
    
    If Action = ResetTimer Then
        For I = 1 To 4
            ElapsedTime(I) = 0
        Next I
        
        BenchTime = 0
        DoEvents
        Exit Function
    End If
    
    TimeNow = Timer
    
    If Action = StartTimer Then
        StartTime(WhichTime) = TimeNow
        BenchTime = ElapsedTime(WhichTime)
        
    ElseIf Action = StopTimer Then
        If TimeNow < StartTime(WhichTime) Then ' benchmark crossed over midnight
            StartTime(WhichTime) = StartTime(WhichTime) - 86400 ' seconds in a day
        End If
        ElapsedTime(WhichTime) = ElapsedTime(WhichTime) + (TimeNow - StartTime(WhichTime))
        BenchTime = ElapsedTime(WhichTime)
        
    ElseIf Action = GetElapsed Then
        BenchTime = ElapsedTime(WhichTime)
        
    Else ' Get Running time
        If TimeNow < StartTime(WhichTime) Then ' benchmark crossed over midnight
            StartTime(WhichTime) = StartTime(WhichTime) - 86400 ' seconds in a day
        End If
        BenchTime = ElapsedTime(WhichTime) + (TimeNow - StartTime(WhichTime))
        
    End If
    
    DoEvents
    
End Function

Sub StartTest(TestWhat2 As Integer)

    Dim timeTotal, timeIO, timeFP As Single
    Dim timeGraphics As Double
    Dim ResultFormat As String
    Dim answer As Boolean
    
    ' RJS - real3d changed timeTotal to be the addition of all the other
    '       times rather than run as a seperate timer
    
    ResultFormat = "#####0.00"
    
    
    'Set swPart = swApp.NewPart
    'swPart.SetTessellationQuality (13) ' Fine performance setting in SW
    
    TestWhat = TestWhat2
    
    ' The Test steps
   'rjs timeTotal = BenchTime(CompleteTime, ResetTimer)
   'rjs timeTotal = BenchTime(CompleteTime, StartTimer)
        
    ' Only used to reset the timer
    timeTotal = BenchTime(CompleteTime, ResetTimer)
    
    ' Turn dialog off, and show status window at top of screen
    frmStart.Hide
    
    ' The test truly begins
    
    timeIO = BenchTime(IOTime, StartTimer)
    OpenFiles
    SaveFiles
    timeIO = BenchTime(IOTime, StopTimer)
    
    GoGraphics
    
    If (TestWhat = CompleteTest) Or (TestWhat = FloatingPointTest) Then
    
        timeFP = BenchTime(FPTime, StartTimer)
        
        AssemblyPerformance
        PartPerformance
        DrawingPerformance
        
        timeFP = BenchTime(FPTime, StopTimer)
        
    End If
    
    CloseFiles
    
    frmStart.txtComplete.Text = "n/a"
    frmStart.txtFloatingPoint.Text = "n/a"
    frmStart.txtIO.Text = "n/a"
    frmStart.txtGraphics.Text = "n/a"
    
    ' Tally the results of the benchmark
    ' Changed to add all the times together for the complete
    ' test time rather than using 4 timers
    ' timeTotal = BenchTime(CompleteTime, StopTimer)
    
    EInfo.WhichTest = TestWhat  ' added rjs
    Select Case TestWhat
        Case CompleteTest
            ' Changed by rjs to add all timers together to get total time
            timeGraphics = (GraphicsBotCaseBaseline / RotBottomCase) ^ (1 / 3) * (GraphicsAssBaseline / RotAssLine) ^ (1 / 3) * (GraphicsAssTBaseline / RotAssLineT) ^ (1 / 3)
            frmStart.txtGraphics.Text = Format(timeGraphics, ResultFormat)
  
            timeIO = IOBaseline / BenchTime(IOTime, GetElapsed)
            frmStart.txtIO.Text = Format(timeIO, ResultFormat)
            
            timeFP = ProcessorBaseline / BenchTime(FPTime, GetElapsed)
            frmStart.txtFloatingPoint.Text = Format(timeFP, ResultFormat)
            
            ' New computation of times
            timeTotal = (GraphicsBotCaseBaseline / RotBottomCase * GraphicsAssBaseline / RotAssLine * GraphicsAssTBaseline / RotAssLineT * timeIO * timeFP) ^ (1 / 5)
            frmStart.txtComplete.Text = Format(timeTotal, ResultFormat)
            
            ' Added by rjs
            EInfo.timeTotal = timeTotal
            EInfo.timeFP = timeFP
            EInfo.timeIO = timeIO
            EInfo.timeGraphics = timeGraphics
            
        Case GraphicsTest
            timeGraphics = (GraphicsBotCaseBaseline / RotBottomCase) ^ (1 / 3) * (GraphicsAssBaseline / RotAssLine) ^ (1 / 3) * (GraphicsAssTBaseline / RotAssLineT) ^ (1 / 3)
            frmStart.txtGraphics.Text = Format(timeGraphics, ResultFormat)
            
            ' Added by rjs
            EInfo.timeGraphics = timeGraphics
        
        Case FloatingPointTest
            timeFP = ProcessorBaseline / BenchTime(FPTime, GetElapsed)
            frmStart.txtFloatingPoint.Text = Format(timeFP, ResultFormat)
            
            ' Added by rjs
            EInfo.timeFP = timeFP
        
        Case IOTest
            timeIO = IOBaseline / BenchTime(IOTime, GetElapsed)
            frmStart.txtIO.Text = Format(timeIO, ResultFormat)
            
            ' Added by rjs
            EInfo.timeIO = timeIO
        
    End Select
    
    ' Signal test is done
    Beep
    Beep
    
    ' Turn status window off, and bring back dialog
    If (BatchMode = False) Then
       frmStart.Show
    
'    answer = MsgBox("Exiting SolidWorks", vbOKOnly, "EXITING")
    Else
       EInfo.WriteAll (HTMLFile)
    End If
 
    On Error GoTo OLEError
    swApp.ExitApp
    
OLEError:
    Select Case Err.Number
    Case 53:
    Case Else:
    End Select
    
    
End Sub

Sub GetPartitionName()
    
    Dim hkey As Long
    Dim lRet As Long
    Dim Msg
    Dim lData As Long
    Dim strData As String

    lRet = RegOpenKeyEx(HKEY_LOCAL_MACHINE, "Software\Microsoft\Windows\CurrentVersion\Setup", 0, KEY_ALL_ACCESS, hkey)

    If lRet <> ERROR_SUCCESS Then
      Select Case lRet
        Case Else
          Msg = "RegOpenKeyEx error"
          MsgBox Msg
      End Select
    End If
    
    lData = 255
    strData = Space$(255)
    lRet = RegQueryValueEx(hkey, "BootDir", 0, REG_SZ, strData, lData)
    
    If lRet <> ERROR_SUCCESS Then
      Select Case lRet
        Case Else
          Msg = "RegQueryValueEx error"
          MsgBox Msg
      End Select
    End If
    
    PartitionName = Left$(strData, lData - 1)
    
    lRet = RegCloseKey(hkey)

End Sub

Sub OpenFiles()

    Dim FileToOpen

    GetPartitionName
    
    FileToOpen = PartitionName & "BenchMarkSW\prod assy demo\overender\overender.SLDASM"
    Set swSubAssembly = swApp.OpenDoc(FileToOpen, 2)
    Set swSubAssembly = swApp.ActivateDoc("overender.SLDASM")
    ' Wait for doc to be fully retrieved before going on
    While (swSubAssembly.IsOpenedViewOnly)
    Wend
    DoEvents
    
    FileToOpen = PartitionName & "BenchMarkSW\prod assy demo\assembly line.SLDASM"
    Set swAssembly = swApp.OpenDoc(FileToOpen, 2)
    Set swAssembly = swApp.ActivateDoc("assembly line.SLDASM")
   ' Wait for doc to be fully retrieved before going on
    While (swAssembly.IsOpenedViewOnly)
    Wend
    DoEvents
    
    If TestWhat <> GraphicsTest Then ' Drawing not needed for graphics test
        FileToOpen = PartitionName & "BenchMarkSW\prod assy demo\overender.SLDDRW"
        Set swDrawing = swApp.OpenDoc(FileToOpen, 3)
        Set swDrawing = swApp.ActivateDoc("overender - ASSY/BOM")
        ' Wait for doc to be fully retrieved before going on
        While (swDrawing.IsOpenedViewOnly)
        Wend
        DoEvents
    End If
    
    FileToOpen = PartitionName & "BenchMarkSW\prod assy demo\FIXTURE\BOTTOM CASE.PRT"
    Set Part = swApp.OpenDoc(FileToOpen, 1)
    Set Part = swApp.ActivateDoc("BOTTOM CASE.PRT")
    ' Wait for doc to be fully retrieved before going on
    While (Part.IsOpenedViewOnly)
    Wend
    DoEvents
    
End Sub

Sub SaveFiles()

    Dim FileToSave
    
    GetPartitionName

    If (TestWhat = CompleteTest) Or (TestWhat = IOTest) Then
        FileToSave = PartitionName & "BenchMarkSW\temp\overender.sldasm"
        swSubAssembly.SaveAs (FileToSave)
        DoEvents
        
        FileToSave = PartitionName & "BenchMarkSW\temp\assembly line.sldasm"
        swAssembly.SaveAs (FileToSave)
        DoEvents
        
        FileToSave = PartitionName & "BenchMarkSW\temp\overender.slddrw"
        swDrawing.SaveAs (FileToSave)
        DoEvents
        
        FileToSave = PartitionName & "BenchMarkSW\temp\bottom case.prt"
        Part.SaveAs (FileToSave)
        DoEvents
    End If
    
End Sub

Sub CloseFiles()

    swApp.QuitDoc ("overender.SLDASM")
    DoEvents
    
    swApp.QuitDoc ("assembly line.SLDASM")
    DoEvents
    
    swApp.QuitDoc ("overender - ASSY/BOM")
    DoEvents
    
    swApp.QuitDoc ("BOTTOM CASE.PRT")
    DoEvents
    
End Sub

Sub GoGraphics()

    Dim swDoc As Object
    
    If (TestWhat = CompleteTest) Or (TestWhat = GraphicsTest) Then
        Set swDoc = swApp.ActivateDoc("BOTTOM CASE.PRT")
        RotBottomCase = BenchTime(GraphicsTime, StartTimer)
        Call GraphicsLoop(swDoc, 800) ' Changed from 100
        
        swDoc.ShowNamedView2 "*Isometric", 7
        swDoc.ViewZoomtofit
        RotBottomCase = BenchTime(GraphicsTime, StopTimer)
        DoEvents
        
        RotAssLine = BenchTime(GraphicsTime, StartTimer)
        Set swDoc = swApp.ActivateDoc("assembly line.SLDASM")
        Call GraphicsLoop(swDoc, 50)
        RotAssLine = BenchTime(GraphicsTime, StopTimer)
    
        DoEvents
        RotAssLineT = BenchTime(GraphicsTime, StartTimer)
        swDoc.ShowConfiguration "Transparency"
        Call GraphicsLoop(swDoc, 6)
        swDoc.ShowConfiguration "Default"
        swAssembly.ShowNamedView2 "good view", -1
        RotAssLineT = BenchTime(GraphicsTime, StopTimer)
        DoEvents
    End If

End Sub

Sub GraphicsLoop(swDoc As Object, SpinCount As Integer)
    Dim I As Integer
    
    swDoc.ViewZoomtofit
    
    ' Start with rotation about X
    For I = 1 To SpinCount
        swDoc.ViewRotateminusx
    Next I
    
    ' Now rotate about Y
    For I = 1 To SpinCount
        swDoc.ViewRotateminusy
    Next I
    
    ' Zoom in and out
    For I = 1 To 20
        swDoc.ViewZoomout
    Next I
    
    For I = 1 To 20
        swDoc.ViewZoomin
    Next I

End Sub

Sub PartPerformance()

    Dim MassInfo As Variant
    Dim I As Integer
    Dim PerfTime As Single
    
    Set Part = swApp.ActivateDoc("BOTTOM CASE.PRT")
    DoEvents
    
    Part.SelectByID "Outer Belly Left", "BODYFEATURE", 0, 0, 0
    Part.FeatEdit
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)
    
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateminusy
    Part.ViewRotateminusy
    Part.ViewRotateminusy
    Part.ViewZoomin
    Part.ViewZoomin
    Part.ViewZoomin
    Part.ViewTranslateplusx
    Part.ViewTranslateplusx
    Part.ViewTranslateplusx
    Part.ViewZoomin
    Part.ViewZoomin
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.CreateCenterLineVB -0.076, 0, 0, 0.062, -0.065, 0
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)
    
    Part.ViewRotateminusy
    Part.ViewRotateminusy
    Part.ViewRotateminusy
    Part.ViewRotateminusx
    Part.ViewRotateminusx
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.InsertSketch
    DoEvents
    Part.SelectByID "O.B.R. Wall", "BODYFEATURE", 0, 0, 0
    Part.FeatEdit
    DoEvents
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateminusx
    For I = 1 To 9
        Part.ViewRotateminusy
    Next I
    For I = 1 To 7
        Part.ViewZoomin
    Next I
    Part.ViewTranslateplusy
    Part.ViewTranslateplusy
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.CreateCenterLineVB 0.076, 0, 0, 0.00661036059176, -0.08075645864629, 0
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewRotateplusy
    Part.ViewRotateplusy
    Part.ViewRotateplusy
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    For I = 1 To 11
        Part.ViewRotateplusx
    Next I
    Part.ViewRotateminusx
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    DoEvents
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.InsertSketch
    
    PerfTime = BenchTime(FPTime, StopTimer)

    For I = 1 To 7
        Part.ViewRotateplusx
    Next I
    Part.ViewZoomtofit
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.SelectByID "R.B. Rear Wall", "BODYFEATURE", 0, 0, 0
    Part.FeatEdit
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    Part.ViewTranslateplusx
    Part.ViewTranslateplusx
    Part.ViewTranslateplusy
    Part.ViewTranslateplusy
    For I = 1 To 7
        Part.ViewZoomin
    Next I
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateminusx
    Part.ViewRotateminusx
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.SelectByID "D1@Sketch29@BOTTOM CASE.SLDPRT", "DIMENSION", 0.1788993474261, -0.02929097851114, -0.07724805625759
    Part.Parameter("D1@Sketch29").SystemValue = 0.004
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    DoEvents
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.EditRebuild
    Part.ViewZoomtofit
    Part.SelectByID "Floor", "BODYFEATURE", 0, 0, 0
    Part.SelectByID "Sketch72", "SKETCH", 0, 0, 0
    Part.ClearSelection
    Part.SelectByID "Right Main/CShaft Lands", "BODYFEATURE", 0, 0, 0
    Part.FeatEdit
    DoEvents
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    For I = 1 To 7
        Part.ViewRotateplusy
    Next I
    Part.ViewRotateminusx
    Part.ViewRotateminusx
    Part.ViewRotateminusx
    For I = 1 To 7
        Part.ViewZoomin
    Next I
    Part.ViewTranslateminusx
    Part.ViewTranslateminusx
    Part.ViewTranslateminusx
    Part.ViewZoomin
    Part.ViewZoomin
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    Part.ViewZoomout
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.SelectByID "D1@Sketch77@BOTTOM CASE.SLDPRT", "DIMENSION", 0.012607347445, 0, -0.241255711217
    Part.ClearSelection
    Part.SelectByID "D1@Sketch77@BOTTOM CASE.SLDPRT", "DIMENSION", 0.01616291964598, -4.058414691599E-05, -0.2395811682933
    Part.Parameter("D1@Sketch77").SystemValue = 0.075
    Part.SelectByID "D1@Sketch77@BOTTOM CASE.SLDPRT", "DIMENSION", 0.005724166962125, -0.006251876179931, -0.2425
    Part.Parameter("D1@Sketch77").SystemValue = 0.062
    DoEvents
    Part.EditRebuild
    Part.ClearSelection
    Part.ViewZoomtofit
    Part.SelectByID "Sketch93", "SKETCH", 0, 0, 0
    Part.ClearSelection
    Part.SelectByID "Boss-Extrude34", "BODYFEATURE", 0, 0, 0
    Part.FeatEdit
    DoEvents
    Part.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewRotateplusy
    Part.ViewRotateplusy
    Part.ViewRotateplusy
    Part.ViewRotateplusy
    Part.ViewRotateplusx
    Part.ViewRotateplusx
    Part.ViewTranslateplusy
    For I = 1 To 7
        Part.ViewZoomin
    Next I
    Part.ViewRotateminusx
    Part.ViewRotateplusy
    Part.ViewTranslateminusx
    Part.ViewTranslateminusx
    Part.ViewTranslateminusx
    Part.ViewTranslateminusx
    Part.ViewZoomin
    Part.ViewZoomin
    Part.ViewTranslateminusy
    Part.ViewTranslateminusy
    Part.ViewZoomin
    
    PerfTime = BenchTime(FPTime, StartTimer)

    Part.ViewDisplayHiddengreyed
    Part.CreateCenterLineVB 0, -0.08826, 0, 0, -0.1087936499821, 0
    Part.ClearSelection
    DoEvents
    Part.InsertSketch
    Part.ViewZoomtofit
    Part.ViewDisplayShaded
    Part.ShowNamedView2 "*Isometric", 7
    Part.ViewZoomtofit
    
    DoEvents
    
    MassInfo = Part.GetMassProperties
    DoEvents

End Sub

Sub AssemblyPerformance()

    Dim MassInfo As Variant
    Dim PerfTime As Single
    
    swAssembly.ForceRebuild
    Set swAssembly = swApp.ActivateDoc("assembly line.SLDASM")
    DoEvents

    swAssembly.ViewDisplayHiddengreyed
    DoEvents
    
    MassInfo = swAssembly.GetMassProperties
    DoEvents

    swAssembly.SelectByID "Press zone", "CONFIGURATIONS", 0, 0, 0
    swAssembly.ClearSelection
    swAssembly.ShowConfiguration "Press zone"
    DoEvents
    
    swAssembly.SelectByID "overender zone", "CONFIGURATIONS", 0, 0, 0
    swAssembly.ClearSelection
    swAssembly.ShowConfiguration "overender zone"
    DoEvents
    
    
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewTranslateminusx
    
    swAssembly.ViewDisplayShaded
    swAssembly.ViewZoomtofit
    swAssembly.ClearSelection
    swAssembly.SelectByID "Default", "CONFIGURATIONS", 0, 0, 0
    swAssembly.ClearSelection
    swAssembly.ShowConfiguration "Default"
    DoEvents
    swAssembly.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)

    swAssembly.ShowNamedView2 "good view", -1
    swAssembly.ViewTranslateplusx
    swAssembly.ViewTranslateplusx
    swAssembly.ViewTranslateminusx
    swAssembly.ViewTranslateplusy
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewTranslateplusy
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewTranslateplusy
    swAssembly.ViewTranslateplusy
    swAssembly.ViewTranslateminusx
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewZoomin
    swAssembly.ViewTranslateplusy
    
    PerfTime = BenchTime(FPTime, StartTimer)
    
    swAssembly.SelectByID "", "FACE", -0.1880395265289, 0.5965512269658, -0.2125149312047
    swAssembly.FeatEdit
    swAssembly.ClearSelection
    
    PerfTime = BenchTime(FPTime, StopTimer)
    
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateplusy
    swAssembly.ViewRotateminusx
    swAssembly.ViewRotateminusx
    swAssembly.ViewRotateminusx
    
    PerfTime = BenchTime(FPTime, StartTimer)

    swAssembly.CreateCenterLineVB 0, 0, 0, -0.1440365660574, -0.1552921432564, 0
    swAssembly.ClearSelection
    swAssembly.InsertSketch
    swAssembly.EditAssembly
    
    PerfTime = BenchTime(FPTime, StopTimer)

    swAssembly.ViewZoomout
    swAssembly.ViewZoomout
    swAssembly.ViewZoomout
    swAssembly.ViewZoomout
    swAssembly.ViewZoomout
    swAssembly.ViewZoomout
    swAssembly.ShowNamedView2 "good view", -1
    
    PerfTime = BenchTime(FPTime, StartTimer)

End Sub

Sub DrawingPerformance()

    Set swDrawing = swApp.ActivateDoc("overender - ASSY/BOM")
    DoEvents

    swDrawing.ViewZoomtofit
    swDrawing.ViewZoomin
    swDrawing.SelectByID "Drawing View6", "DRAWINGVIEW", 0.4558268760447, 0.2590293877012, 0
    swDrawing.EditSketch
    swDrawing.ClearSelection
    swDrawing.CreateCenterLineVB 0.01326005566975, 0.5369207265384, 0, 0.01326005566975, -0.5032882339849, 0
    swDrawing.CreateSectionViewAt 0.7190778657517, 0.1843440727861, 0, 0, 0
    DoEvents
    
    swDrawing.SelectByID "Drawing View13", "DRAWINGVIEW", 0.6292382422803, 0.1932166402745, 0
    swDrawing.EditSketch
    swDrawing.ClearSelection
    swDrawing.CreateCircle -0.155575, 0.3146543958778, 0, -0.2089293569104, 0.4324560480833, 0
    swDrawing.CreateDetailViewAt 0.4140410046626, 0.3060384930061, 0
    DoEvents
    
    swDrawing.ClearSelection
    swDrawing.SelectByID "ASSY/BOM", "SHEET", 0.03274492830122, 0.0584572050673, 0
    swDrawing.EditSketch
    swDrawing.SelectByID "", "FACE", 0.1904865927685, 0.1911273466949, -1499.4668
    swDrawing.InsertModelDimensions 2
    swDrawing.SelectByID "", "FACE", 0.4965681006422, 0.1900826999104, -1499.4144125
    swDrawing.InsertModelDimensions 2
    swDrawing.SelectByID "D1@Boss-Extrude-Thin2@overender-3@Drawing View3/overender frame-1@overender", "DIMENSION", 0.219736702736, 0.3258867819126, 0
    DoEvents
    
    swDrawing.Parameter("D1@Boss-Extrude-Thin2@overender frame.Part").SystemValue = 0.762
    swDrawing.EditRebuild
    DoEvents
    
    swDrawing.SelectByID "D1@Base-Extrude-Thin@overender-1@Drawing View6/overender frame-1@overender", "DIMENSION", 0.4903002199349, 0.3269314286971, 0
    swDrawing.Parameter("D1@Base-Extrude-Thin@overender frame.Part").SystemValue = 0.254
    swDrawing.EditRebuild
    DoEvents

End Sub
